@@ -67,13 +67,14 @@ class PETRAViewer(QtWidgets.QMainWindow):
         if has_converter:
             self.converter = Converter(self)
 
-        self.setCentralWidget(None)
+        self.scrollable_widget = QtWidgets.QMainWindow(self)
+        self._ui.scrollArea.setWidget(self.scrollable_widget)
 
-        self.setDockOptions(QtWidgets.QMainWindow.AnimatedDocks |
-                            QtWidgets.QMainWindow.AllowNestedDocks |
-                            QtWidgets.QMainWindow.AllowTabbedDocks)
+        self.scrollable_widget.setDockOptions(QtWidgets.QMainWindow.AnimatedDocks |
+                                              QtWidgets.QMainWindow.AllowNestedDocks |
+                                              QtWidgets.QMainWindow.AllowTabbedDocks)
 
-        self.setTabPosition(QtCore.Qt.LeftDockWidgetArea, QtWidgets.QTabWidget.North)
+        self.scrollable_widget.setTabPosition(QtCore.Qt.LeftDockWidgetArea, QtWidgets.QTabWidget.North)
 
         self.settings = self.get_settings(options)
 
@@ -321,22 +322,6 @@ class PETRAViewer(QtWidgets.QMainWindow):
         if self.configuration['cube_view']:
             self.cube_view.fill_roi()
 
-    # ----------------------------------------------------------------------
-    def _batch_process(self, mode):
-        if mode == 'files':
-            file_names, _ = QtWidgets.QFileDialog.getOpenFileNames(self, 'Select files',
-                                                                   self.file_browser.current_folder(),
-                                                                   'NEXUS files (*.nxs)')
-        else:
-            dir_name = QtWidgets.QFileDialog.getExistingDirectory(self, 'Select directory',
-                                                                  self.file_browser.current_folder())
-
-            file_names = [name for name in os.listdir(dir_name) if name.endswith('.nxs')]
-
-        save_dir = QtWidgets.QFileDialog.getExistingDirectory(self, 'Save to', self.file_browser.current_folder())
-        if save_dir:
-            self.data_pool.batch_process_rois(file_names, save_dir, '.txt')
-
     # ----------------------------------------------------------------------
     def _convert(self):
         self.converter.show(self.frame_view.current_file())
@@ -348,15 +333,6 @@ class PETRAViewer(QtWidgets.QMainWindow):
     # ----------------------------------------------------------------------
     def _setup_menu(self):
         if self.configuration['sardana']:
-            batch_menu = QtWidgets.QMenu('Batch process', self)
-
-            action = batch_menu.addAction("Process files...")
-            action.triggered.connect(lambda checked, x='files': self._batch_process(x))
-
-            action = batch_menu.addAction("Process folder...")
-            action.triggered.connect(lambda checked, x='folder': self._batch_process(x))
-
-            self.menuBar().addMenu(batch_menu)
 
             if has_converter:
                 space_menu = QtWidgets.QMenu('Space', self)
@@ -395,7 +371,7 @@ class PETRAViewer(QtWidgets.QMainWindow):
 
         dock.setStyleSheet("""QDockWidget {font-size: 14pt; font-weight: bold;}""")
 
-        self.addDockWidget(location, dock)
+        self.scrollable_widget.addDockWidget(location, dock)
         self._menu_view.addAction(dock.toggleViewAction())
 
         return widget, dock
@@ -451,6 +427,9 @@ class PETRAViewer(QtWidgets.QMainWindow):
         self.rois_view.save_ui_settings(settings)
         self.frame_view.save_ui_settings(settings)
 
+        settings.setValue("InternalWindow/geometry", self.scrollable_widget.saveGeometry())
+        settings.setValue("InternalWindow/state", self.scrollable_widget.saveState())
+
         settings.setValue("MainWindow/geometry", self.saveGeometry())
         settings.setValue("MainWindow/state", self.saveState())
 
@@ -470,6 +449,16 @@ class PETRAViewer(QtWidgets.QMainWindow):
         except:
             pass
 
+        try:
+            self.scrollable_widget.restoreGeometry(settings.value("InternalWindow/geometry"))
+        except:
+            pass
+
+        try:
+            self.scrollable_widget.restoreState(settings.value("InternalWindow/state"))
+        except:
+            pass
+
         if self.configuration['sardana']:
             self.file_browser.load_ui_settings(settings)
 
