@@ -185,7 +185,7 @@ class FrameView(AbstractWidget):
     # ----------------------------------------------------------------------
     def new_coordinate(self, source, x_value, y_value, pos):
 
-        self._coordinate_label.setText(f'{x_value}, {y_value}')
+        self._coordinate_label.setText(f'Current coordinates: X: {x_value}, Y: {y_value}')
 
         if source == 'main':
             self._second_view.move_marker(pos)
@@ -521,11 +521,11 @@ class FrameView(AbstractWidget):
 
     # ----------------------------------------------------------------------
     def _save(self):
-        default_name = self._parent.current_folder() + '/roi_{}'.format(self.data_pool.get_roi_index(self.my_id))
+        default_name = self._parent.get_current_folder()
         file_name, _ = QtWidgets.QFileDialog.getSaveFileName(self, 'Save as', default_name,
                                                              'Windows Bitmap (*.bmp);; Joint Photographic Experts Group (*jpg);; Portable Network Graphics (*.png);; Portable Pixmap (*.ppm); X11 Bitmap (*.xbm);; X11 Pixmap (*.xpm)')
         if file_name:
-            pix = QtGui.QPixmap(self._ui.view_layout.size())
+            pix = QtGui.QPixmap(self._ui.view_widget.size())
             self._ui.view_widget.render(pix)
             pix.save(file_name)
 
